%global pkgname qrcode
%global sum Python QR Code image generator
%global sum_core QR Code image generator (core library)

%global desc \
This module uses the Python Imaging Library (PIL) to allow for the \
generation of QR Codes.

%global desc_core \
Core Python 2 module for QR code generation. Does not contain image rendering.

Name:           python-%{pkgname}
Version:        5.3
Release:        %mkrel 1
Summary:        %{sum}

License:        BSD
URL:            https://github.com/lincolnloop/python-qrcode
Source0:        https://files.pythonhosted.org/packages/source/q/qrcode/qrcode-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python2-devel
BuildRequires:  python-setuptools
BuildRequires:  python-imaging
BuildRequires:  python-six
BuildRequires:  python-mock

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-imaging
BuildRequires:  python3-six
BuildRequires:  python3-mock
Group:       Development/Python

Requires:       python-imaging
Requires:       %{name}-core = %{version}-%{release}

%description
%{desc}


%package core
Requires:       python-six
Conflicts:      python-qrcode < 5.0
Summary:        %{sum_core}
Group:          Development/Python

%description core
%{desc_core}


%package -n python3-%{pkgname}
Summary:        %{sum}
Requires:       python3-imaging
# For entry point:
Requires:       python3-setuptools
Requires:       python3-%{pkgname}-core = %{version}-%{release}
Group:          Development/Python

%description -n python3-%{pkgname}
%{desc}


%package -n python3-%{pkgname}-core
Requires:       python3-six
Summary:        %{sum_core}
Group:          Development/Python

%description -n python3-%{pkgname}-core
%{desc_core}

%prep
%setup -q -n %{pkgname}-%{version}

# The pure plugin requires pymaging which is not packaged in Fedora.
rm qrcode/image/pure.py*

# Remove shebang
sed -i '1d'  qrcode/console_scripts.py


%build
%py2_build
%py3_build

%install
%py2_install
# Be sure binscripts are Python 3
rm %{buildroot}%{_bindir}/*
# Do not install tests
rm -r %{buildroot}%{python2_sitelib}/%{pkgname}/tests
%py3_install
rm -r %{buildroot}%{python3_sitelib}/%{pkgname}/tests

#
# In previous iterations of the package, the qr script had been
# renamed to qrcode. This was an unnecessary change from upstream.
#
# We cary this symlink to maintain compat with old packages.
#
ln -s qr %{buildroot}%{_bindir}/qrcode

%check
# in lieue of a real test suite
modules=$(find qrcode -name '*.py' \
          | grep -v __init__ \
          | sort \
          | sed -e 's|/|.|g' \
          | sed -e 's|.py$||g');


for m in $modules;
do
    %{__python2} -c "import $m"
done

for m in $modules;
do
    %{__python3} -c "import $m"
done

%files
%{python2_sitelib}/%{pkgname}/image/svg.py*
%{python2_sitelib}/%{pkgname}/image/pil.py*


%files core
%doc README.rst CHANGES.rst
%license LICENSE
%dir %{python2_sitelib}/%{pkgname}/
%dir %{python2_sitelib}/%{pkgname}/image
%{python2_sitelib}/%{pkgname}*.egg-info
%{python2_sitelib}/%{pkgname}/*.py*
%{python2_sitelib}/%{pkgname}/image/__init__.py*
%{python2_sitelib}/%{pkgname}/image/base.py*


%files -n python3-%{pkgname}
%{_bindir}/qr
%{_bindir}/qrcode
%{_mandir}/man1/qr.1*
%{python3_sitelib}/%{pkgname}/image/svg.py*
%{python3_sitelib}/%{pkgname}/image/pil.py*
%{python3_sitelib}/%{pkgname}/image/__pycache__/svg.*
%{python3_sitelib}/%{pkgname}/image/__pycache__/pil.*


%files  -n python3-%{pkgname}-core
%doc README.rst CHANGES.rst
%license LICENSE
%dir %{python3_sitelib}/%{pkgname}/
%dir %{python3_sitelib}/%{pkgname}/image
%dir %{python3_sitelib}/%{pkgname}/image/__pycache__
%{python3_sitelib}/%{pkgname}*.egg-info
%{python3_sitelib}/%{pkgname}/*.py*
%{python3_sitelib}/%{pkgname}/__pycache__
%{python3_sitelib}/%{pkgname}/image/__init__.py*
%{python3_sitelib}/%{pkgname}/image/base.py*
%{python3_sitelib}/%{pkgname}/image/__pycache__/__init__.*
%{python3_sitelib}/%{pkgname}/image/__pycache__/base.*


%changelog
* Sun Nov 20 2016 joequant <joequant> 5.3-1.mga6
+ Revision: 1068412
- imported package python-qrcode

